#!/usr/bin/env python

"""
Created on Fri Jul 20 09:13:55 2012

@author: chris

Legal Information:
All information contained herein is, and remains the property of 
Vena Engineering Corporation. This source code contains proprietary 
information of Vena Engineering Corporation. It is intended solely 
for the information and use of parties operating and maintaining 
the equipment provided by Vena Engineering. Such proprietary 
information may not be used, reproduced, or disclosed to any other 
parties for any other purpose without the expressed written 
permission of Vena Engineering Corporation. The intellectual and 
technical concepts contained herein are proprietary to Vena 
Engineering Corporation and may be covered by U.S. and Foreign 
Patents, patents in process, and are protected by trade secret 
or copyright law. Dissemination of this information or reproduction 
of this material is strictly forbidden unless prior written permission 
is obtained from Vena Engineering Corporation. 
"""

from PyQt4 import QtCore, QtGui
import sys
import limitedangletorquemotor

class MySpinBox(QtGui.QSpinBox):
    def __init__(self, minimum, maximum, value, parent=None):
        super(MySpinBox, self).__init__(parent)
        self.setRange(minimum, maximum)
        self.setValue(value)
    
class MyButton(QtGui.QPushButton):
    def __init__(self, label, callback = None, parent=None):
        super(MyButton, self).__init__(label, parent)
        self.clicked.connect(callback)

class TorqueMotorDialog(QtGui.QDialog):

    message_received = QtCore.pyqtSignal(str)

    def __init__(self, parent=None):
        super(TorqueMotorDialog, self).__init__(parent)
        
        self.m = limitedangletorquemotor.LimitedTorqueMotor('192.168.1.200')
        
        self.setWindowTitle("Limited Angle Torque Motor")
        
        self.homeOffset = MySpinBox(-1000, 1000, 0)
        self.useOffsetcb = QtGui.QCheckBox()
        self.accelSpinBox = MySpinBox(0, 5000000, 500000)
        self.velSpinBox = MySpinBox(0, 500000, 500000)
        self.widthSpinBox = MySpinBox(10, 1250, 1250)
        self.moveTypeComboBox = QtGui.QComboBox()        
        self.moveTypeComboBox.addItems(['Full Sweep', 'Random', 'Butterfly'])
        startButton = MyButton('Start', self.onStart)
        stopButton = MyButton('Stop', self.onStop)
        homeButton = MyButton('Home', self.onHome)
        offButton = MyButton('Off', self.onOff)
        
        self.useOffsetcb.toggled.connect(self.onUseHomeOffsetChanged)
        
        #layout
        mainLayout = QtGui.QGridLayout()
        self.setLayout(mainLayout)
        
        mainLayout.addWidget(QtGui.QLabel('Use Home Offset:'), 0, 0)
        mainLayout.addWidget(self.useOffsetcb, 0, 1)
        
        mainLayout.addWidget(QtGui.QLabel('Home Offset:'), 1, 0)
        mainLayout.addWidget(self.homeOffset, 1, 1)
        
        mainLayout.addWidget(offButton, 2, 0)
        mainLayout.addWidget(homeButton, 2, 1)
        
        mainLayout.addWidget(QtGui.QLabel('Acceleration:'), 3, 0)
        mainLayout.addWidget(self.accelSpinBox, 3, 1)

        mainLayout.addWidget(QtGui.QLabel('Velocity:'), 4, 0)
        mainLayout.addWidget(self.velSpinBox, 4, 1)

        mainLayout.addWidget(QtGui.QLabel('Sweep Width:'), 5, 0)
        mainLayout.addWidget(self.widthSpinBox, 5, 1)

        mainLayout.addWidget(QtGui.QLabel('Move Type:'), 6, 0)
        mainLayout.addWidget(self.moveTypeComboBox, 6, 1)

        mainLayout.addWidget(startButton, 7, 0)
        mainLayout.addWidget(stopButton, 7, 1)
        
        self.onUseHomeOffsetChanged()

    def onUseHomeOffsetChanged(self):
        self.homeOffset.setEnabled(self.useOffsetcb.isChecked())       

    def onStart(self):
        v = self.velSpinBox.value()
        a = self.accelSpinBox.value()
        w = self.widthSpinBox.value()
        pattern = self.moveTypeComboBox.currentText()
        self.m.move_pattern(v, a, w, pattern)

    def onStop(self):
        self.m.stop()

    def onHome(self):
        if self.useOffsetcb.isChecked():
            self.m.home(self.homeOffset.value())            
        else:
            newHome = self.m.home()
            self.homeOffset.setValue(newHome)

    def onOff(self):
        self.m.off()

if __name__ == '__main__':

    app = QtGui.QApplication(sys.argv)
    dialog = TorqueMotorDialog()
    sys.exit(dialog.exec_())    
